@@ -5,16 +5,16 @@ import logging
 
 __author__ = "Mikko Hellsing"
 __license__ = "BSD"
-__version__ = '12.2'
-__maintainer__ = "Mario César Señoranis Ayala"
-__email__ = "mariocesar@creat1va.com"
-__status__ = "Beta"
+__version__ = '12.5.0'
+__maintainer__ = "Jazzband"
+__email__ = "mariocesar@humanzilla.com"
 
 
 class NullHandler(logging.Handler):
     def emit(self, record):
         pass
 
+
 # Add a logging handler that does nothing to silence messages with no logger
 # configured
 logging.getLogger('sorl').addHandler(NullHandler())
