@@ -2,6 +2,8 @@ from __future__ import unicode_literals, with_statement
 import re
 import os
 import subprocess
+import logging
+from collections import OrderedDict
 
 from django.utils.encoding import smart_str
 from django.core.files.temp import NamedTemporaryFile
@@ -10,8 +12,8 @@ from sorl.thumbnail.base import EXTENSIONS
 from sorl.thumbnail.compat import b
 from sorl.thumbnail.conf import settings
 from sorl.thumbnail.engines.base import EngineBase
-from sorl.thumbnail.compat import OrderedDict
 
+logger = logging.getLogger(__name__)
 
 size_re = re.compile(r'^(?:.+) (?:[A-Z]+) (?P<x>\d+)x(?P<y>\d+)')
 
@@ -53,11 +55,16 @@ class Engine(EngineBase):
             args.append(fp.name)
             args = map(smart_str, args)
             p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-            p.wait()
+            returncode = p.wait()
             out, err = p.communicate()
 
-            if err:
-                raise Exception(err)
+            if returncode:
+                raise EngineError(
+                    "The command %r exited with a non-zero exit code and printed this to stderr: %s"
+                    % (args, err)
+                )
+            elif err:
+                logger.error("Captured stderr: %s", err)
 
             thumbnail.write(fp.read())
 
@@ -78,7 +85,7 @@ class Engine(EngineBase):
         """
         if image['size'] is None:
             args = settings.THUMBNAIL_IDENTIFY.split(' ')
-            args.append(image['source'])
+            args.append(image['source'] + '[0]')
             p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             p.wait()
             m = size_re.match(str(p.stdout.read()))
@@ -94,7 +101,7 @@ class Engine(EngineBase):
             fp.write(raw_data)
             fp.flush()
             args = settings.THUMBNAIL_IDENTIFY.split(' ')
-            args.append(fp.name)
+            args.append(fp.name + '[0]')
             p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             retcode = p.wait()
         return retcode == 0
@@ -105,7 +112,7 @@ class Engine(EngineBase):
 
         if settings.THUMBNAIL_CONVERT.endswith('gm convert'):
             args = settings.THUMBNAIL_IDENTIFY.split()
-            args.extend(['-format', '%[exif:orientation]', image['source']])
+            args.extend(['-format', '%[exif:orientation]', image['source'] + '[0]'])
             p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             p.wait()
             result = p.stdout.read().strip()
@@ -134,6 +141,17 @@ class Engine(EngineBase):
             image['options']['auto-orient'] = None
         return image
 
+    def _flip_dimensions(self, image):
+        if settings.THUMBNAIL_CONVERT.endswith('gm convert'):
+            args = settings.THUMBNAIL_IDENTIFY.split()
+            args.extend(['-format', '%[exif:orientation]', image['source'] + '[0]'])
+            p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            p.wait()
+            result = p.stdout.read().strip()
+            return result and result != 'unknown' and int(result) in [5, 6, 7, 8]
+        else:
+            return False
+
     def _colorspace(self, image, colorspace):
         """
         `Valid colorspaces
@@ -170,3 +188,7 @@ class Engine(EngineBase):
         image['options']['gravity'] = 'center'
         image['options']['extent'] = '%sx%s' % (geometry[0], geometry[1])
         return image
+
+
+class EngineError(Exception):
+    pass
