@@ -11,6 +11,8 @@ except ImportError:
     import ImageFile
     import ImageDraw
 
+EXIF_ORIENTATION = 0x0112
+
 
 def round_corner(radius, fill):
     """Draw a round corner"""
@@ -63,17 +65,26 @@ class Engine(EngineBase):
             return False
         return True
 
+    def colorspace(self, image, geometry, options):
+        """
+        Wrapper for ``_colorspace``
+        """
+        colorspace = options['colorspace']
+        format = options['format']
+
+        return self._colorspace(image, colorspace, format)
+
     def _cropbox(self, image, x, y, x2, y2):
         return image.crop((x, y, x2, y2))
 
     def _orientation(self, image):
         try:
             exif = image._getexif()
-        except:
+        except Exception:
             exif = None
 
         if exif:
-            orientation = exif.get(0x0112)
+            orientation = exif.get(EXIF_ORIENTATION)
 
             if orientation == 2:
                 image = image.transpose(Image.FLIP_LEFT_RIGHT)
@@ -82,25 +93,38 @@ class Engine(EngineBase):
             elif orientation == 4:
                 image = image.transpose(Image.FLIP_TOP_BOTTOM)
             elif orientation == 5:
-                image = image.rotate(-90).transpose(Image.FLIP_LEFT_RIGHT)
+                image = image.rotate(-90, expand=1).transpose(Image.FLIP_LEFT_RIGHT)
             elif orientation == 6:
-                image = image.rotate(-90)
+                image = image.rotate(-90, expand=1)
             elif orientation == 7:
-                image = image.rotate(90).transpose(Image.FLIP_LEFT_RIGHT)
+                image = image.rotate(90, expand=1).transpose(Image.FLIP_LEFT_RIGHT)
             elif orientation == 8:
-                image = image.rotate(90)
+                image = image.rotate(90, expand=1)
 
         return image
 
-    def _colorspace(self, image, colorspace):
+    def _flip_dimensions(self, image):
+        try:
+            exif = image._getexif()
+        except (AttributeError, IOError, KeyError, IndexError):
+            exif = None
+
+        if exif:
+            orientation = exif.get(0x0112)
+            return orientation in [5, 6, 7, 8]
+
+        return False
+
+    def _colorspace(self, image, colorspace, format):
         if colorspace == 'RGB':
-            if image.mode == 'RGBA':
+            # Pillow JPEG doesn't allow RGBA anymore. It was converted to RGB before.
+            if image.mode == 'RGBA' and format != 'JPEG':
                 return image  # RGBA is just RGB + Alpha
             if image.mode == 'LA' or (image.mode == 'P' and 'transparency' in image.info):
                 newimage = image.convert('RGBA')
                 transparency = image.info.get('transparency')
                 if transparency is not None:
-                    mask = Image.new('L', image.size, color=transparency)
+                    mask = image.convert('RGBA').split()[-1]
                     newimage.putalpha(mask)
                 return newimage
             return image.convert('RGB')
