@@ -1,6 +1,7 @@
 # encoding=utf-8
 
 from __future__ import unicode_literals
+import decimal
 import logging
 import sys
 import re
@@ -9,13 +10,13 @@ from functools import wraps
 
 from django.template import Library, Node, NodeList, TemplateSyntaxError
 from django.utils.encoding import smart_str
+from django.utils.six import text_type
 from django.conf import settings
 
 from sorl.thumbnail.conf import settings as sorl_settings
 from sorl.thumbnail import default
 from sorl.thumbnail.images import ImageFile, DummyImageFile
 from sorl.thumbnail.parsers import parse_geometry
-from sorl.thumbnail.compat import text_type
 from sorl.thumbnail.shortcuts import get_thumbnail
 
 
@@ -38,7 +39,7 @@ def safe_filter(error_output=''):
             except Exception as err:
                 if sorl_settings.THUMBNAIL_DEBUG:
                     raise
-                logger.error('Thumbnail filter failed: %s' % err.message,
+                logger.error('Thumbnail filter failed: %s' % str(err),
                              exc_info=sys.exc_info())
                 return error_output
 
@@ -63,7 +64,7 @@ class ThumbnailNodeBase(Node):
 
             error_message = 'Thumbnail tag failed'
 
-            if settings.TEMPLATE_DEBUG:
+            if context.template.engine.debug:
                 try:
                     error_message_template = (
                         "Thumbnail tag failed "
@@ -134,7 +135,11 @@ class ThumbnailNode(ThumbnailNodeBase):
             else:
                 options[key] = value
 
-        thumbnail = get_thumbnail(file_, geometry, **options)
+        thumbnail = None
+        if file_:
+            thumbnail = get_thumbnail(file_, geometry, **options)
+        elif sorl_settings.THUMBNAIL_DUMMY:
+            thumbnail = DummyImageFile(geometry)
 
         if not thumbnail or (isinstance(thumbnail, DummyImageFile) and self.nodelist_empty):
             if self.nodelist_empty:
@@ -167,6 +172,20 @@ def resolution(file_, resolution_string):
     """
     A filter to return the URL for the provided resolution of the thumbnail.
     """
+    if sorl_settings.THUMBNAIL_DUMMY:
+        dummy_source = sorl_settings.THUMBNAIL_DUMMY_SOURCE
+        source = dummy_source.replace('%(width)s', '(?P<width>[0-9]+)')
+        source = source.replace('%(height)s', '(?P<height>[0-9]+)')
+        source = re.compile(source)
+        try:
+            resolution = decimal.Decimal(resolution_string.strip('x'))
+            info = source.match(file_).groupdict()
+            info = {dimension: int(int(size) * resolution) for (dimension, size) in info.items()}
+            return dummy_source % info
+        except (AttributeError, TypeError, KeyError):
+            # If we can't manipulate the dummy we shouldn't change it at all
+            return file_
+
     filename, extension = os.path.splitext(file_)
     return '%s@%s%s' % (filename, resolution_string, extension)
 
