@@ -14,7 +14,7 @@ class KVStoreTestCase(unittest.TestCase):
         def thread_cache_backend():
             cache_backends.append(kv.cache)
 
-        for x in range(2):
+        for _ in range(2):
             t = threading.Thread(target=thread_cache_backend)
             t.start()
             t.join()
